Module cygrind_utils::parser

source ·
Parser for the ULTRAKILL cyber grind pattern (cgp) format

Structs

Representation of an individual square on a cyber grind pattern
Generic error type for parsing failures
Representation of a cgp

Enums

Representation of the prefabs available on the official editor

Functions

Tries to parse a string to a Pattern