Module cygrind_utils::util

source ·
Utilities for drawing patterns (extracting a colour from height information)

Functions

Ported method for extracting colour information from height from the official editor
Generate a pattern with random heights in the range -10..=20, and random prefabs for each cell