Function cygrind_utils::util::random_pattern
source · pub fn random_pattern() -> PatternExpand description
Generate a pattern with random heights in the range -10..=20, and random prefabs for each cell
pub fn random_pattern() -> PatternGenerate a pattern with random heights in the range -10..=20, and random prefabs for each cell